@@ -6,6 +6,12 @@
 
 #pragma once
 
+#include <QtGlobal>
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+#include <KPropertiesDialog>
+#else
+#include <KPropertiesDialogPlugin>
+#endif
 #include <KPropertiesDialog>
 
 class BalooFilePropertiesPlugin : public KPropertiesDialogPlugin
